﻿using System;
using System.Data;
using System.Linq;
using System.Data.SqlClient;
using System.Configuration;
using SoftwareWebDidactico.Modelo;
using System.Web.Security;
using System.Web.UI.WebControls;
using Telerik.Web.UI;

namespace SoftwareWebDidactico.EDP
{
    public partial class Entrada : System.Web.UI.Page
    {
        DataClassesDataContext db = new DataClassesDataContext();
        ConsultasBD consultas = new ConsultasBD();

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                consultas.actualizarVistasEspacio(int.Parse(Request.QueryString["id"]));

                var resultado = (from esp in db.EntradaEspacio
                                 join c in db.CategoriaEspacio
                                 on esp.categoria equals c.idCategoriaEspacio
                                 where esp.idEntrada.ToString() == Request.QueryString["id"]
                                 select new { esp.pregunta, esp.resumen, esp.fecha, esp.usuario, c.categoria, esp.respuestas }).First();

                categoriaLabel.Text = "CATEGORÍA > " + resultado.categoria.ToUpper();
                preguntaLabel.Text = resultado.pregunta;
                resumenLabel.Text = resultado.resumen;
                respuestasLabel.Text = resultado.respuestas + " respuestas";

                cargarRespuestas();

                /* Habilitar botones de eliminar */

                if (Roles.GetRolesForUser().Count()>0)
                {
                    String[] roles = Roles.GetRolesForUser();
                    Guid idRol = (from r in db.aspnet_Roles
                                  where r.RoleName == roles[0]
                                  select r.RoleId).First<Guid>();

                    var listaFunciones = (from funciones in db.FuncionesRol
                                          where funciones.idRol.Equals(idRol)
                                          select funciones.funcion).ToList();

                    MembershipUser m = Membership.GetUser(User.Identity.Name);
                    Guid idUsuario = (Guid)m.ProviderUserKey;

                    /* Si es el que escribió la entrada o un administrador del F.A.Q */
                    if (idUsuario.Equals(resultado.usuario) || (listaFunciones.Contains(7)) )
                    {
                        eliminarEntradaButton.Visible = true;
                    }

                    /* Habilitar botón para las respuestas */

                    foreach (DataListItem dli in respuestasDataList.Items)
                    {
                        Label usuario = (Label)dli.FindControl("idUsuario");

                        if(idUsuario.ToString() == usuario.Text)
                        {
                            LinkButton botonEliminar = (LinkButton)dli.FindControl("DeleteButton");

                            if(botonEliminar!=null)
                                botonEliminar.Visible = true;
                        }    
                    }
                }
            }
        }

        private void cargarRespuestas()
        {
            SqlConnection con = new SqlConnection();
            SqlCommand cmd = new SqlCommand();

            con.ConnectionString = ConfigurationManager.ConnectionStrings["DBSofWebDidConnectionString"].ConnectionString;

            SqlParameter[] param = new SqlParameter[1];
            param[0] = new SqlParameter("@pregunta", SqlDbType.Int, 16);
            param[0].Value = Request.QueryString["id"];

            cmd.CommandType = CommandType.StoredProcedure;
            cmd.CommandText = "SeleccionRespuestasEspacio";
            cmd.Connection = con;
            cmd.Parameters.AddRange(param);

            DataSet ds = new DataSet();
            SqlDataAdapter da = new SqlDataAdapter(cmd);
            da.Fill(ds);

            respuestasDataList.DataSource = ds;
            respuestasDataList.DataBind();

            string autor = consultas.autorEntrada(Request.QueryString["id"]);
            fechaLabel.Text = consultas.fechaEntrada(Request.QueryString["id"]);

            if (autor == null)
            {
                autorLabel.Text = "Anónimo";
            }
            else
            {
                autorLabel.Text = consultas.autorEntrada(Request.QueryString["id"]);
            }

        }

        protected void postearRadButton_Click(object sender, EventArgs e)
        {
            int idPregunta = int.Parse(Request.QueryString["id"]);

            if (Roles.GetRolesForUser().Count()>0)
            {
                MembershipUser m = Membership.GetUser(User.Identity.Name);
                Guid key = (Guid)m.ProviderUserKey;
                db.AñadirNuevaRespuestaEspacio(idPregunta, respuestaCKEditor.Text, key);
            }
            else
            {
                db.AñadirNuevaRespuestaEspacio(idPregunta, respuestaCKEditor.Text, null);
            }

            respuestaCKEditor.Text = "";

            consultas.actualizarRespuestasEspacio(idPregunta);

            respuestasLabel.Text = Convert.ToString(consultas.respuestasEspacio(idPregunta) + " respuestas");

            cargarRespuestas();
        }

        /* Eliminar entradas y respuestas */

        protected void EliminarEntrada(object sender, EventArgs e)
        {
            int entrada = int.Parse(Request.QueryString["id"]);

            int idCategoria = (from en in db.EntradaEspacio
                               where en.idEntrada == entrada
                               select en.categoria).First();

            var resultado = (from esp in db.EntradaEspacio
                             join c in db.CategoriaEspacio
                             on esp.categoria equals c.idCategoriaEspacio
                             where esp.idEntrada.ToString() == Request.QueryString["id"]
                             select new { esp.idEntrada }).First();

            db.EliminarEntradaEspacio(resultado.idEntrada);

            Response.Redirect("~/EDP/CategoriaEspacio.aspx?id=" + idCategoria.ToString());
        }

        protected void EliminarRespuesta(object source, DataListCommandEventArgs e)
        {
            Label idRespuesta = (Label)e.Item.FindControl("idRespuesta");
            int entrada = int.Parse(Request.QueryString["id"]);

            int idCategoria = (from en in db.EntradaEspacio
                               where en.idEntrada == entrada
                               select en.categoria).First();

            db.EliminarRespuestaEntradaEspacio(Convert.ToInt16(idRespuesta.Text));
            consultas.decrementarRespuestasEspacio(int.Parse(Request.QueryString["id"]));



            Response.Redirect("~/EDP/CategoriaEspacio.aspx?id="+idCategoria.ToString());
        }

    }
}