﻿using System;
using System.Collections;
using System.Linq;
using System.Data.SqlClient;
using Telerik.Web.UI;
using SoftwareWebDidactico.Modelo;
using System.Configuration;
using System.Web.UI.WebControls;

namespace SoftwareWebDidactico
{
    public partial class NuevaPreguntaFAQ : System.Web.UI.Page
    {
        ConsultasBD consultas = new ConsultasBD();
        DataClassesDataContext db = new DataClassesDataContext();

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                if (Request.QueryString["id"] != null)
                {
                    int idEntrada = int.Parse(Request.QueryString["id"]);

                    RadButton3.Text = "Actualizar entrada";

                    preguntaRadTextBox.Text = consultas.tituloEntradaFAQ(idEntrada);
                    resumenCKEditor.Text = consultas.resumenEntradaFAQ(idEntrada);
                    categoriaRadComboBox.SelectedValue = consultas.categoriaEntradaFAQ(idEntrada).ToString();

                    ArrayList etiquetas = consultas.etiquetasEntradaFAQ(idEntrada);

                    for (int i = 0; i < etiquetas.Count; i++)
                    {
                        MenuItem et = (MenuItem)etiquetas[i];
                        etiquetasRadListBox.Items.Add(new Telerik.Web.UI.RadListBoxItem(et.Text, et.Value));
                    }
                }
            }
        }

        protected void añadirEtiquetaRadButton_Click(object sender, EventArgs e)
        {
            etiquetasRadListBox.Items.Add(new Telerik.Web.UI.RadListBoxItem(etiquetaRadComboBox.Text, etiquetaRadComboBox.SelectedValue));
        }

        protected void eliminarEtiquetaRadButton_Click(object sender, EventArgs e)
        {
            etiquetasRadListBox.Items.Remove(etiquetasRadListBox.SelectedItem);
        }

        protected bool existeEtiqueta(string etiqueta)
        {
            DataClassesDataContext db = new DataClassesDataContext();

            var resultado = ((from e in db.EtiquetaFAQ
                    where e.etiqueta == etiqueta
                     select e).ToList()).Count;

            if (resultado > 0)
            {
                return true;
            }
            else
            {
                return false;
            }
        }

        protected void crearEntradaRadButton_Click(object sender, EventArgs e)
        {
            if (RadButton3.Text == "Actualizar entrada")
            {
                int idEntrada = int.Parse(Request.QueryString["id"]);

                ArrayList etiquetasAnteriores = consultas.etiquetasEntradaFAQ(idEntrada);
                ArrayList itemsEtiquetasAnteriores = itemsEtiquetas(etiquetasAnteriores);
                ArrayList itemsEtiquetasNuevas = new ArrayList();

                for (int indP = 0; indP < etiquetasRadListBox.Items.Count; indP++)
                {
                    RadListBoxItem item = (RadListBoxItem)etiquetasRadListBox.Items[indP];
                    itemsEtiquetasNuevas.Add(item.Text);
                }


                /* Borrar las etiquetas que ya no están asignadas a esa entrada */
                for (int i = 0; i < itemsEtiquetasAnteriores.Count; i++)
                {
                    MenuItem et = (MenuItem)itemsEtiquetasAnteriores[i];

                    if (!itemsEtiquetasNuevas.Contains(et.Text))
                        db.EliminarEtiquetaEntradaFAQ(int.Parse(et.Value), idEntrada);
                }

                /*Añadir las nuevas etiquetas */
                ArrayList etiquetas = new ArrayList();
                for (int indP = 0; indP < etiquetasRadListBox.Items.Count; indP++)
                {
                    RadListBoxItem item = (RadListBoxItem)etiquetasRadListBox.Items[indP];

                    if (!existeEtiqueta(item.Text))
                    {
                        int etiquetaID = db.AñadirEtiquetaFAQ(item.Text);

                        etiquetas.Add(etiquetaID.ToString());
                    }
                    else
                    {
                        etiquetas.Add(item.Value);
                    }
                }

                ArrayList nombresEtsAnteriores = nombresEtiquetasAnteriores(etiquetasAnteriores);
                /* Insertar las etiquetas a la pregunta */
                foreach (string idEtiqueta in etiquetas)
                {
                    if(!nombresEtsAnteriores.Contains(consultas.nombreEtiqueta(int.Parse(idEtiqueta))))
                        db.AñadirPreguntaEtiquetaFAQ(idEntrada, int.Parse(idEtiqueta));
                }

                /* Actualizar campos de la entrada del F.A.Q */

                Faq f = db.Faq.Single(ent => ent.id == idEntrada);

                f.pregunta = preguntaRadTextBox.Text;
                f.resumen = resumenCKEditor.Text;
                f.faq = int.Parse(categoriaRadComboBox.SelectedValue);

                db.SubmitChanges();

                limpiarCampos();
            }

            else
            {
                ArrayList etiquetas = new ArrayList();
                DataClassesDataContext db = new DataClassesDataContext();

                /* Crear etiquetas */
                for (int indP = 0; indP < etiquetasRadListBox.Items.Count; indP++)
                {
                    RadListBoxItem item = (RadListBoxItem)etiquetasRadListBox.Items[indP];

                    if (!existeEtiqueta(item.Text))
                    {
                        int etiquetaID = db.AñadirEtiquetaFAQ(item.Text);

                        etiquetas.Add(etiquetaID.ToString());
                    }
                    else
                    {
                        etiquetas.Add(item.Value);
                    }
                }

                /* Crear la entrada al FAQ */

                int entradaFAQID = db.AñadirNuevaEntradaFAQ(preguntaRadTextBox.Text, int.Parse(categoriaRadComboBox.SelectedValue), resumenCKEditor.Text);

                /* Insertar las etiquetas a la pregunta */
                foreach (string idEtiqueta in etiquetas)
                {
                    db.AñadirPreguntaEtiquetaFAQ(entradaFAQID, int.Parse(idEtiqueta));
                }

                limpiarCampos();

                /* Redirigir a la entrada creada */
                Response.Redirect("~/FAQ/CuestionFAQ.aspx?id=" + entradaFAQID.ToString());
            }
        }

        protected void limpiarCampos()
        {
            preguntaRadTextBox.Text = "";
            resumenCKEditor.Text = "";
            etiquetasRadListBox.Items.Clear();
            etiquetaRadComboBox.Text = "";
        }

        protected ArrayList itemsEtiquetas(ArrayList etiquetas)
        {
            ArrayList nombres = new ArrayList();

            for (int i = 0; i < etiquetas.Count; i++)
            {
                MenuItem et = (MenuItem)etiquetas[i];
                nombres.Add(et);
            }

            return nombres;
        }

        protected ArrayList nombresEtiquetasAnteriores(ArrayList etiquetas)
        {
            ArrayList nombres = new ArrayList();

            for (int i = 0; i < etiquetas.Count; i++)
            {
                MenuItem et = (MenuItem)etiquetas[i];
                nombres.Add(et.Text);
            }

            return nombres;
        }
    }
}