﻿using System.Collections;
using System.Linq;
using System.Web.UI.WebControls;
using SoftwareWebDidactico.Modelo;

namespace SoftwareWebDidactico
{
    public class ConsultasBD
    {
        DataClassesDataContext db = new DataClassesDataContext();

        #region F.A.Q

        public int preguntasFAQ()
        {
            return ((from f in db.Faq
                     select f).ToList()).Count;
        }

        public ArrayList categoriasFAQ()
        {
            var resultado = from c in db.CategoriaFaq
                            orderby c.preferencia
                            select new MenuItem { Value = c.idCategoria.ToString(), Text = c.categoria };

            ArrayList categorias = new ArrayList();
            foreach (MenuItem mi in resultado)
            {
                categorias.Add(mi);
            }

            return categorias;
        }

        public int respuestasFAQ(int idPregunta)
        {
            var respuestas = (from f in db.Faq
                             where f.id == idPregunta
                             select f.respuestas).First();

            return int.Parse(respuestas.ToString());
        }

        public void actualizarVistasFAQ(int idPregunta)
        {
            Faq faq = db.Faq.Single(f => f.id == idPregunta);
            faq.vistas = faq.vistas + 1;

            db.SubmitChanges();
        }

        public void actualizarRespuestasFAQ(int idPregunta)
        {
            Faq faq = db.Faq.Single(f => f.id == idPregunta);
            faq.respuestas = faq.respuestas + 1;

            db.SubmitChanges();
        }

        /* Datos entrada F.A.Q */
        public string categoriaFAQ(int idFAQ)
        {
            return (from f in db.CategoriaFaq
                    where f.idCategoria == idFAQ
                    select f.categoria).First<string>();
        }

        public string resumenEntradaFAQ(int idFAQ)
        {
            return (from f in db.Faq
                              where f.id == idFAQ
                              select f.resumen).First();
        }

        public string tituloEntradaFAQ(int idFAQ)
        {
            return (from f in db.Faq
                    where f.id == idFAQ
                    select f.pregunta).First();
        }

        public int? categoriaEntradaFAQ(int idFAQ)
        {
            return (from f in db.Faq
                    where f.id == idFAQ
                    select f.faq).First<int?>();
        }

        public ArrayList etiquetasEntradaFAQ(int idFAQ)
        {
            var resultado = from e in db.EtiquetaFAQ
                            join f in db.PreguntasEtiquetaFAQ
                            on e.idEtiqueta equals f.etiqueta
                            where f.pregunta == idFAQ
                            select new MenuItem { Value=e.idEtiqueta.ToString(), Text=e.etiqueta};

            ArrayList etiquetas = new ArrayList();
            foreach (MenuItem et in resultado)
            {
                etiquetas.Add(et);
            }

            return etiquetas;
        }
        /* Fin Datos entrada F.A.Q */

        public string nombreEtiqueta(int idEtiqueta)
        {
            return (from e in db.EtiquetaFAQ
                    where e.idEtiqueta == idEtiqueta
                    select e.etiqueta).First();
        }

        #endregion

        #region Autoevaluación

        public string lineaCategoria(int idCategoria)
        {
            return (from c in db.CategoriaTema
                    where c.idCategoria == idCategoria
                    select c.linea).First<string>();
        }

        public int preguntasTest(int idTest)
        {
            return ((from p in db.PreguntaTest
                     join t in db.Test
                     on p.test equals t.idTest
                     where p.test == idTest
                     select p).ToList()).Count;
        }

        #endregion

        #region Búsqueda

        public ArrayList resultadosBusquedaDocumentacion(string cadena)
        {
            var resultado = (from d in db.Documentación
                             where d.texto.Contains(cadena)
                             select new ListItem
                             {
                                 Value = d.id.ToString(),
                                 Text = "Documentación-" + d.titulo
                             }).Union(
                                from t in db.TemaC
                                where t.texto.Contains(cadena)
                                select new ListItem
                                {
                                    Value = t.idTema.ToString(),
                                    Text = "Temario-" + t.titulo
                                }).Union(
                                    from ep in db.EntradaEspacio
                                    where (ep.pregunta.Contains(cadena) || ep.resumen.Contains(cadena))
                                    select new ListItem
                                    {
                                        Value = ep.idEntrada.ToString(),
                                        Text = "Duda de usuario-" + ep.pregunta.ToString()
                                    }).Union(
                                        from fa in db.Faq
                                        where fa.resumen.Contains(cadena)
                                        select new ListItem
                                        {
                                            Value = fa.id.ToString(),
                                            Text = "Entrada F.A.Q-" + fa.pregunta.ToString()
                                        })
                                        .Union(
                                            from r in db.RespuestaEntradaEspacio
                                            where r.respuesta.Contains(cadena)
                                            select new ListItem
                                            {
                                                Value = r.entrada.ToString(),
                                                Text = "Respuesta del espacio de preguntas-" + r.respuesta.ToString()
                                            })/*.Union(
                                                from de in db.CategoriaDescarga
                                                where de.descripción.Contains(cadena)
                                                select new ListItem
                                                {
                                                    Value = de.idCategoriaDescarga.ToString(),
                                                    Text = "Categoría descarga-" + de.nombre.ToString()
                                                })*/.Union(
                                                    from de in db.Archivo
                                                    where de.nombreArchivo.Contains(cadena) || de.descripcion.Contains(cadena)
                                                    select new ListItem
                                                    {
                                                        Value = de.grupo.ToString() +"/"+ de.categoria.ToString(),
                                                        Text = "Archivo de descarga-" + de.nombreArchivo.ToString()
                                                    });

            ArrayList resultados = new ArrayList();
            foreach (ListItem li in resultado)
            {
                resultados.Add(li);
            }

            return resultados;
        }

        #endregion

        #region Espacio de preguntas

        public void actualizarVistasEspacio(int idEntrada)
        {
            EntradaEspacio ee = db.EntradaEspacio.Single(ent => ent.idEntrada == idEntrada);
            ee.vistas = ee.vistas + 1;

            db.SubmitChanges();
        }

        public void actualizarRespuestasEspacio(int idEntrada)
        {
            EntradaEspacio ee = db.EntradaEspacio.Single(ent => ent.idEntrada== idEntrada);
            ee.respuestas = ee.respuestas + 1;

            db.SubmitChanges();
        }

        public void decrementarRespuestasEspacio(int idEntrada)
        {
            EntradaEspacio ee = db.EntradaEspacio.Single(ent => ent.idEntrada == idEntrada);
            ee.respuestas = ee.respuestas - 1;

            db.SubmitChanges();
        }

        public int entradasEspacioPreguntas()
        {
            return ((from e in db.EntradaEspacio
                     select e).ToList()).Count;
        }

        public ArrayList categoriasEspacioPreguntas()
        {
            var resultado = from c in db.CategoriaEspacio
                            orderby c.preferencia
                            select new MenuItem { Value = c.idCategoriaEspacio.ToString(), Text = c.categoria };

            ArrayList categorias = new ArrayList();
            foreach (MenuItem mi in resultado)
            {
                categorias.Add(mi);
            }

            return categorias;
        }

        public int respuestasEspacio(int idEntrada)
        {
            var respuestas = (from e in db.EntradaEspacio
                              where e.idEntrada == idEntrada
                              select e.respuestas).First();

            return int.Parse(respuestas.ToString());
        }

        public string autorEntrada(string idPregunta)
        {
            return (from e in db.EntradaEspacio
                     join u in db.aspnet_Users
                     on e.usuario equals u.UserId
                     where e.idEntrada == int.Parse(idPregunta)
                     select u.UserName).FirstOrDefault();
        }

        public string fechaEntrada(string idPregunta)
        {
            return (from e in db.EntradaEspacio
                    where e.idEntrada == int.Parse(idPregunta)
                    select e.fecha.ToString()).First();
        }

        #endregion
    }
}